@@ -1,23 +1,23 @@
-# Copyright (C) 1997-2000  Adrian Trapletti
-#
-# This library is free software; you can redistribute it and/or
-# modify it under the terms of the GNU Library General Public
-# License as published by the Free Software Foundation; either
-# version 2 of the License, or (at your option) any later version.
-#
-# This library is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-# Library General Public License for more details.
-#
-# You should have received a copy of the GNU Library General Public
-# License along with this library; if not, write to the Free
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-
-#
-# Mostly time series tests
-#
+## Copyright (C) 1997-2000  Adrian Trapletti
+##
+## This program is free software; you can redistribute it and/or modify
+## it under the terms of the GNU General Public License as published by
+## the Free Software Foundation; either version 2, or (at your option)
+## any later version.
+##
+## This program is distributed in the hope that it will be useful, but
+## WITHOUT ANY WARRANTY; without even the implied warranty of
+## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+## General Public License for more details.
+##
+## A copy of the GNU General Public License is available via WWW at
+## http://www.gnu.org/copyleft/gpl.html.  You can also obtain it by
+## writing to the Free Software Foundation, Inc., 59 Temple Place,
+## Suite 330, Boston, MA  02111-1307  USA. 
 
+##
+## Mostly time series tests
+##
 
 runs.test <- function (x)
 {
@@ -181,7 +181,7 @@ adf.test <- function (x, alternative = c("stationary", "explosive"),
             class = "htest")
 }
 
-white.test <- function (object, ...) { UseMethod("white.test") }
+white.test <- function (x, ...) UseMethod("white.test")
 
 white.test.default <- function (x, y, qstar = 2, q = 10, range = 4,
                                 type = c("chisq","F"), scale = TRUE)
@@ -302,7 +302,7 @@ white.test.ts <- function (x, lag = 1, qstar = 2, q = 10, range = 4,
                  method = METHOD, data.name = DNAME, arguments = ARG), class = "htest")
 }
 
-terasvirta.test <- function (object, ...) { UseMethod("terasvirta.test") }
+terasvirta.test <- function (x, ...) UseMethod("terasvirta.test")
 
 terasvirta.test.default <- function (x, y, type = c("chisq","F"), scale = TRUE)
 {
